@@ -86,7 +86,13 @@ def read_type(file, data_type, endianness):
 
 
 class TdmsFile(object):
-    """Represents a TDMS file."""
+    """Represents a TDMS file.
+
+    Instance Attributes:
+    --------------------
+        objects: A dictionary of objects within the file, with the object paths
+                 as keys.
+    """
 
     def __init__(self, file):
         """Initialise a new TDMS file object from an open
@@ -107,7 +113,7 @@ class TdmsFile(object):
         previous_segment = None
         while True:
             try:
-                segment = TdmsSegment(tdms_file)
+                segment = _TdmsSegment(tdms_file)
             except EOFError:
                 # We've finished reading the file
                 break
@@ -159,7 +165,7 @@ class TdmsFile(object):
         return self.objects[self._path(group, channel)].data
 
 
-class TdmsSegment(object):
+class _TdmsSegment(object):
     def __init__(self, f):
         """Read the lead in section of a segment"""
 
@@ -209,6 +215,9 @@ class TdmsSegment(object):
             self.next_segment_pos = (self.position +
                     self.next_segment_offset + lead_size)
 
+    def __repr__(self):
+        return "<TdmsSegment at position %d>" % self.position
+
     def read_metadata(self, f, objects, previous_segment=None):
         """Read segment metadata section and update object information"""
 
@@ -235,7 +244,7 @@ class TdmsSegment(object):
             else:
                 obj = TdmsObject(object_path)
                 objects[object_path] = obj
-            obj.read_metadata(f)
+            obj._read_metadata(f)
             if (self.toc["kTocNewObjList"] or
                     object_path not in [o.path for o in self.ordered_objects]):
                 self.ordered_objects.append(obj)
@@ -287,11 +296,11 @@ class TdmsSegment(object):
                 for obj in self.ordered_objects:
                     if obj.has_data:
                         object_data[obj.path] = (
-                                obj.read_values(f, endianness))
+                                obj._read_values(f, endianness))
 
                 for obj in self.ordered_objects:
                     if obj.has_data:
-                        obj.update_data(object_data[obj.path])
+                        obj._update_data(object_data[obj.path])
 
     def _read_interleaved_numpy(self, f, data_objects, endianness):
         """Read interleaved data where all channels have a numpy type"""
@@ -316,7 +325,7 @@ class TdmsSegment(object):
             # be correct
             object_data.dtype = (
                     np.dtype(obj.data_type.nptype).newbyteorder(endianness))
-            obj.update_data(object_data)
+            obj._update_data(object_data)
             data_pos += obj.data_type.length
 
     def _read_interleaved(self, f, data_objects, endianness):
@@ -326,26 +335,38 @@ class TdmsSegment(object):
         object_data = {}
         points_added = {}
         for obj in data_objects:
-            object_data[obj.path] = obj.new_segment_data()
+            object_data[obj.path] = obj._new_segment_data()
             points_added[obj.path] = 0
         while any([points_added[o.path] < o.number_values
                 for o in data_objects]):
             for obj in data_objects:
                 if points_added[obj.path] < obj.number_values:
                     object_data[obj.path][points_added[obj.path]] = (
-                            obj.read_value(f, endianness))
+                            obj._read_value(f, endianness))
                     points_added[obj.path] += 1
         for obj in data_objects:
-            obj.update_data(object_data[obj.path])
+            obj._update_data(object_data[obj.path])
 
 
 class TdmsObject(object):
-    """Represents an object in a TDMS file"""
+    """Represents an object in a TDMS file.
+
+    Instance Attributes:
+    --------------------
+        path: The TDMS object path.
+        properties: Dictionary of TDMS properties defined for this object,
+                    for example the start time and time increment for
+                    waveforms.
+        has_data: Boolean, true if there is data associated with the object.
+        data: NumPy array containing data if there is data, otherwise None.
+        data_type: DataType object describing the data type.
+    """
 
     def __init__(self, path):
         self.path = path
         self.data = None
         self.properties = {}
+        self.properties_with_type = {}
         self.raw_data_index = 0
         self.data_type = None
         self.dimension = 1
@@ -353,7 +374,10 @@ class TdmsObject(object):
         self.data_size = 0
         self.has_data = True
 
-    def read_metadata(self, f):
+    def __repr__(self):
+        return "<TdmsObject with path %s>" % self.path
+
+    def _read_metadata(self, f):
         """Read object metadata and update object information"""
 
         s = f.read(4)
@@ -408,24 +432,28 @@ class TdmsObject(object):
                 value = read_string(f)
             else:
                 value = read_type(f, prop_data_type, '<')
-            self.properties[prop_name] = (prop_data_type.name, value)
+            self.properties_with_type[prop_name] = (prop_data_type.name, value)
+            self.properties[prop_name] = value
             log.debug("Property %s: %s" % (prop_name, value))
 
     def property(self, property_name):
         """Returns the value of a property"""
 
-        return self.properties[property_name][1]
+        return self.properties[property_name]
 
     def time_track(self):
         """Return an array of time for this channel"""
 
-        increment = self.property('wf_increment')
-        offset = self.property('wf_start_offset')
+        try:
+            increment = self.property('wf_increment')
+            offset = self.property('wf_start_offset')
+        except KeyError:
+            raise KeyError("Object does not have time properties available.")
 
         return np.arange(
                 offset, offset + len(self.data) * increment, increment)
 
-    def new_segment_data(self):
+    def _new_segment_data(self):
         """Return a new array to read the data of the current section into"""
 
         if self.data_type.nptype is not None:
@@ -433,7 +461,7 @@ class TdmsObject(object):
         else:
             return [None] * self.number_values
 
-    def read_value(self, file, endianness):
+    def _read_value(self, file, endianness):
         """Read a single value from the given file"""
 
         if self.data_type.nptype is not None:
@@ -442,19 +470,19 @@ class TdmsObject(object):
             return np.fromfile(file, dtype=dtype, count=1)
         return read_type(file, self.data_type, endianness)
 
-    def read_values(self, file, endianness):
+    def _read_values(self, file, endianness):
         """Read all values for this object from a contiguous segment"""
 
         if self.data_type.nptype is not None:
             dtype = (np.dtype(self.data_type.nptype).
                     newbyteorder(endianness))
             return np.fromfile(file, dtype=dtype, count=self.number_values)
-        data = self.new_segment_data()
+        data = self._new_segment_data()
         for i in range(self.number_values):
             data[i] = read_type(file, self.data_type, endianness)
         return data
 
-    def update_data(self, new_data):
+    def _update_data(self, new_data):
         """Update the object data with a new array of data"""
 
         log.debug("Adding %d data points to data for %s" %
@@ -479,6 +507,6 @@ def read(file_path):
             o.path,
             o.raw_data_index,
             (o.data_type.name, o.dimension, o.number_values),
-            o.properties))
+            o.properties_with_type))
         for o in tdms_file.objects])
     return (metadata, data)
